@@ -1,15 +1,16 @@
 #' Forward Search algorithm in network meta-analysis
 #'
 #' @description
-#' This function employs the Forward Search algorithm to detect outliers
-#' and influential studies fitted in network meta-analysis model from graph-theory.
-#' This is an outlying diagnostic tool to detect outliers and studies that are potential
-#' sources for heterogeneity and inconsistency in network meta-analysis.
+#' This function employs the Forward Search algorithm to detect
+#' outliers and influential studies fitted in network meta-analysis
+#' model from graph-theory.  This is an outlying diagnostic tool to
+#' detect outliers and studies that are potential sources for
+#' heterogeneity and inconsistency in network meta-analysis.
 #'
 #' Monitoring measures during the search are:
 #' \itemize{
-#' \item outlier detection measures (standardized residuals, Cook's distance,
-#'   ratio of variance);
+#' \item outlier detection measures (standardized residuals, Cook's
+#'   distance, ratio of variance);
 #' \item ranking measures (P-scores);
 #' \item heterogeneity and inconsistency measures (Q statistics for
 #'   overall heterogeneity / inconsistency, inconsistency by
@@ -17,15 +18,15 @@
 #'   between direct and indirect evidence by back-calculation method).
 #' }
 #'
-#' A description of the outlier detection methodology can be found in Petropoulou et
-#' al. (2021).
+#' A description of the outlier detection methodology can be found in
+#' Petropoulou et al. (2021).
 #'
 #' @param TE Estimate of treatment effect, i.e. difference between
 #'   first and second treatment (e.g. log odds ratio, mean difference,
 #'   or log hazard ratio). This can also be a pairwise object
-#'   (i.e. the result of pairwise function of netmeta package).
-#'   In this case, the pairwise object should include the following:
-#'   TE, seTE, treat1, treat2, studlab
+#'   (i.e. the result of pairwise function of netmeta package).  In
+#'   this case, the pairwise object should include the following: TE,
+#'   seTE, treat1, treat2, studlab
 #' @param seTE Standard error of treatment estimate.
 #' @param treat1 Label/Number for first treatment.
 #' @param treat2 Label/Number for second treatment.
@@ -52,8 +53,9 @@
 #' @param sm A character string indicating underlying summary measure,
 #'   e.g., \code{"RD"}, \code{"RR"}, \code{"OR"}, \code{"ASD"},
 #'   \code{"HR"}, \code{"MD"}, \code{"SMD"}, or \code{"ROM"}.
-#' @param Isub A vector for the studies to be included in the initial subset (default: NULL, the initial subset
-#'   not specified by the user).
+#' @param Isub A vector for the studies to be included in the initial
+#'   subset (default: NULL, the initial subset not specified by the
+#'   user).
 #' @param reference Reference treatment group.
 #' @param small.values A character string indicating if small values
 #'   are considered beneficial (option:"good") or harmfull
@@ -61,36 +63,39 @@
 #'   computation. The default value is considered benefial outcome
 #'   ("good").
 #' @param n_cores The number of cores that the process is running
-#'   using the parallel (default: NULL, the process is running
-#'   using all the available cores)
+#'   using the parallel (default: NULL, the process is running using
+#'   all the available cores)
+#' @param \dots Additional arguments passed on to
+#'   \code{\link{netmeta}}.
 #'
 #' @details
-#' FS algorithm for network meta-analysis
-#' model from graph theory is described in Petropoulou et al. (2021).
+#' FS algorithm for network meta-analysis model from graph theory is
+#' described in Petropoulou et al. (2021).
 #'
-#' Let \emph{n} be the number of treatments and let
-#' \emph{m} be the number of pairwise treatment comparisons.  If there
-#' are only two-arm studies, \emph{m} is equal to the number of studies. Let
-#' TE and seTE be the vectors of observed effects and their standard
+#' Let \emph{n} be the number of treatments and let \emph{m} be the
+#' number of pairwise treatment comparisons.  If there are only
+#' two-arm studies, \emph{m} is equal to the number of studies. Let TE
+#' and seTE be the vectors of observed effects and their standard
 #' errors.  Comparisons belonging to multi-arm studies are identified
 #' by identical study labels (argument \code{studlab}).
 #'
-#' The FS algorithm is an outlier diagnostic iterative procedure. FS algorithm
-#' apart from three steps. It starts with a subset of studies and it
-#' gradually adds studies until all studies entered.  After the
-#' search, statistical measures are monitored for sharp changes.
+#' The FS algorithm is an outlier diagnostic iterative procedure. FS
+#' algorithm apart from three steps. It starts with a subset of
+#' studies and it gradually adds studies until all studies entered.
+#' After the search, statistical measures are monitored for sharp
+#' changes.
 #'
-#' In more detail, the FS algorithm starts with an initial subset of the dataset with
-#' size \emph{l}.  Let (argument \code{P}) (eg. \emph{P} = 100) a
-#' large number of candidate subset of studies with size \emph{l}.
-#' The candidate subset that optimize the criterion (argument
-#' \code{crit1}) is taken as the initial subset (considered ideally to be
-#' outlying-free).  Criterion (\code{crit1}) to be used for selecting
-#' the initial subset, can be the minimum of median absolute residuals
-#' \code{"R"} or the maximum of median absolute likelihood
-#' contributions \code{"L"}.  It is conventionally refer this subset
-#' as basic set, whereas the remaining studies constitute the
-#' non-basic set.
+#' In more detail, the FS algorithm starts with an initial subset of
+#' the dataset with size \emph{l}. Let (argument \code{P})
+#' (eg. \emph{P} = 100) a large number of candidate subset of studies
+#' with size \emph{l}. The candidate subset that optimize the
+#' criterion (argument \code{crit1}) is taken as the initial subset
+#' (considered ideally to be outlying-free).  Criterion (\code{crit1})
+#' to be used for selecting the initial subset, can be the minimum of
+#' median absolute residuals \code{"R"} or the maximum of median
+#' absolute likelihood contributions \code{"L"}. It is conventionally
+#' refer this subset as basic set, whereas the remaining studies
+#' constitute the non-basic set.
 #'
 #' The FS algorithm gradually adds studies from the non-basic to the
 #' basic subset based on how close the former studies are to the
@@ -103,16 +108,16 @@
 #' according to their closeness to the basic set by adding the study
 #' that optimize the criterion from non-basic set to basic set.
 #'
-#' The process is repeated until all studies are entered into the basic
-#' set.  The number of iterations of algorithm \emph{index} is equal
-#' to the total number of studies minus the number of studies entered
-#' into the initial subset. Through the FS procedure,
-#' parameter estimates (summary estmates, heterogeneity
-#' estimator) and other statistics of interest (outlying measures,
-#' heterogeneity and inconsistency measures, ranking measures) are
-#' monitored. In each iteration, network meta-analysis model from
-#' graph theory [Rucker, 2012] is fitted (\code{netmeta} function)
-#' with R package \bold{netmeta} [Rucker et al., 2018].
+#' The process is repeated until all studies are entered into the
+#' basic set.  The number of iterations of algorithm \emph{index} is
+#' equal to the total number of studies minus the number of studies
+#' entered into the initial subset. Through the FS procedure,
+#' parameter estimates (summary estmates, heterogeneity estimator) and
+#' other statistics of interest (outlying measures, heterogeneity and
+#' inconsistency measures, ranking measures) are monitored. In each
+#' iteration, network meta-analysis model from graph theory (Rücker,
+#' 2012) is fitted (\code{netmeta} function) with R package
+#' \bold{netmeta}.
 #'
 #' Monitoring statistical measures for each FS iteration can be:
 #'
@@ -122,19 +127,19 @@
 #' variance-covariance matrix
 #'
 #' \bold{Ranking measures:}
-#' P-scores for ranking of treatments [Rucker G & Schwarzer G (2015)]
+#' P-scores for ranking of treatments (Rücker G & Schwarzer G, 2015)
 #' for each basic set with implementation of (\code{netrank} function)
 #' from R package \bold{netmeta}.
 #'
 #' \bold{Heterogeneity and inconsistency measures:}
 #' Overall heterogeneity / inconsistency Q statistic (\code{Q}) This
 #' is the design-based decomposition of Cochran Q as provided by Krahn
-#' et al.(2013); Overall heterogeneity Q statistic (\code{Q});
+#' et al. (2013); Overall heterogeneity Q statistic (\code{Q});
 #' Between-designs Q statistic (\code{Q}), based on a random effects
 #' model with square-root of between-study variance estimated embedded
 #' in a full design-by-treatment interaction model.  Implementation
 #' with (\code{decomp.design} function) from R package \bold{netmeta};
-#' Z-values [Dias et al., 2010; Konig et al., 2013] for comparison
+#' Z-values (Dias et al., 2010; König et al., 2013) for comparison
 #' between direct and indirect evidence in
 #' each iteration of forward search algorithm.  By monitoring
 #' difference of direct and indirect evidence, potential sources of
@@ -172,35 +177,36 @@
 #' \emph{Statistics in Medicine},
 #' \bold{29}, 932--44
 #'
-#' Konig J, Krahn U, Binder H (2013):
+#' König J, Krahn U, Binder H (2013):
 #' Visualizing the flow of evidence in network meta-analysis and
 #' characterizing mixed treatment comparisons.
 #' \emph{Statistics in Medicine},
 #' \bold{32}, 5414--29
 #'
-#' Krahn U, Binder H, Konig J (2013):
+#' Krahn U, Binder H, König J (2013):
 #' A graphical tool for locating inconsistency in network meta-analyses.
 #' \emph{BMC Medical Research Methodology},
 #' \bold{13}, 35
 #'
-#' Petropoulou M, Salanti G, Rucker G, Schwarzer G, Moustaki I,
+#' Petropoulou M, Salanti G, Rücker G, Schwarzer G, Moustaki I,
 #' Mavridis D (2021):
-#' A forward search algorithm for detection of extreme study effects
-#' in network meta-analysis.
-#' \emph{Manuscript}
+#' A forward search algorithm for detecting extreme study effects in
+#' network meta-analysis.
+#' \emph{Statistics in Medicine}
 #'
-#' Rucker G (2012):
+#' Rücker G (2012):
 #' Network meta-analysis, electrical networks and graph theory.
 #' \emph{Research Synthesis Methods},
 #' \bold{3}, 312--24
 #'
-#' Rucker G, Schwarzer G (2015):
+#' Rücker G, Schwarzer G (2015):
 #' Ranking treatments in frequentist network meta-analysis works
 #' without resampling methods.
 #' \emph{BMC Medical Research Methodology},
 #' \bold{15}, 58
 #'
 #' @examples
+#' \dontrun{
 #' data(smokingcessation, package = "netmeta")
 #' smokingcessation$id <- 1:nrow(smokingcessation)
 #'
@@ -213,9 +219,9 @@
 #'
 #' # Forward search algorithm
 #' #
-#' FSresult <- NMAoutlier(p1, Isub = c(1, 2, 3), small.values = "bad", n_cores = 2)
-#'
-#' \dontrun{
+#' FSresult <- NMAoutlier(p1, P = 1, small.values = "bad", n_cores = 2)
+#' FSresult
+#' 
 #' data(smokingcessation, package = "netmeta")
 #'
 #' # Transform data from arm-based to contrast-based format
@@ -259,7 +265,8 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
                        P = 100,
                        sm,
                        Isub = NULL,
-                       reference = "", small.values = "good", n_cores = NULL) {
+                       reference = "", small.values = "good", n_cores = NULL,
+                       ...) {
 
 
   ## Check arguments
@@ -288,7 +295,8 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
   TE <- eval(mf[[match("TE", names(mf))]],
              data, enclos = sys.frame(sys.parent()))
   ##
-  if (inherits(TE, "pairwise")) {
+  if (inherits(TE, "pairwise") ||
+      is.data.frame(TE) & !is.null(attr(TE, "pairwise"))) {
     sm <- attr(TE, "sm")
     ##
     seTE <- TE$seTE
@@ -501,7 +509,7 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
 
     ## NMA for the whole dataset
     ##
-    res <- nma(TE, seTE, treat1, treat2, studlab, reference, names.treat)
+    res <- nma(TE, seTE, treat1, treat2, studlab, reference, names.treat, ...)
 
     ## initialize lists for variance-covariance matrix of basic set
     ## for each step of FS algorithm
@@ -518,7 +526,7 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
       ## Take the initial subset
       Isub <- c(InitialSubset(TE, seTE, treat1, treat2, studlab,
                               crit1, studies, P, reference,
-                              t1.label, t2.label, n_cores)$set)
+                              t1.label, t2.label, n_cores, ...)$set)
     }
 
     ## Define the initial basic set
@@ -530,7 +538,7 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
     ind.bs <- which(studlab %in% bs)
     ##
     S1 <- netmet(TE, seTE, treat1, treat2, studlab,
-                 ind.bs, reference, small.values, names.treat)
+                 ind.bs, reference, small.values, names.treat, ...)
     ##
     ## Initial basic set
     ##
@@ -576,7 +584,7 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
         ##
         model <- netmeta(TE, seTE, treat1, treat2, studlab,
                          comb.random = TRUE, reference.group = reference,
-                         subset = ind.bs)
+                         subset = ind.bs, ...)
         ##
         t.basic <- (model$tau) ^ 2              # heterogeneity
         e.basic <- model$TE.random[, reference] # summary estimate
@@ -641,7 +649,7 @@ NMAoutlier <- function(TE, seTE, treat1, treat2, studlab,
 
       ##
       Si <- netmet(TE, seTE, treat1, treat2, studlab,
-                   ind.bs, reference, small.values, names.treat)
+                   ind.bs, reference, small.values, names.treat, ...)
       ##
       ## Basic set
       ##
